jit_rebox_array_int

Function jit_rebox_array_int 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn jit_rebox_array_int( vec_ptr: *mut LustInt, vec_len: usize, vec_cap: usize, array_value_ptr: *mut Value, ) -> u8
Rebox Vec back to Array Value IMPORTANT: Writes the specialized vec data back into the EXISTING Rc<RefCell<Vec>> This ensures the original array is updated, not replaced